package com.huimv.farm.damsubsidy.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.damsubsidy.common.utils.Result;
import com.huimv.farm.damsubsidy.common.utils.ResultCode;
import com.huimv.farm.damsubsidy.entity.SysUser;
import com.huimv.farm.damsubsidy.mapper.SysUserMapper;
import com.huimv.farm.damsubsidy.service.ISysUserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2023-04-26
 */
@Service
public class SysUserServiceImpl extends ServiceImpl<SysUserMapper, SysUser> implements ISysUserService {

    @Autowired
    private SysUserMapper userMapper;
    @Override
    public Result loginMultilevel(HttpServletRequest httpServletRequest, Map<String,String> paramsMap) {
        //TODO 验证码接口暂时不写，验证码验证接口写在此接口之前，这里默认验证码已经正确！
        String phone = paramsMap.get("phone");
        if (!phone.matches("1[3-9]\\d{9}")) {
            return new Result(ResultCode.FAIL, "手机号格式不正确");
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", phone);
        SysUser sysUser = userMapper.selectOne(queryWrapper);
        if (ObjectUtil.isEmpty(sysUser)) {
            return new Result(ResultCode.DATA_NULL, "用户暂未注册，请注册！");
        } else {
            return new Result(ResultCode.SUCCESS, sysUser);
        }
    }

    @Override
    public Result add(HttpServletRequest httpServletRequest,Map<String,String> paramsMap) {

        SysUser user = new SysUser();
        user.setUserType(Integer.parseInt(paramsMap.get("type")));
        user.setUserName(paramsMap.get("userName"));
        user.setIdCard(paramsMap.get("idCord"));
        user.setPhone(paramsMap.get("phone"));
        user.setIdCardFrontUrl(paramsMap.get("idCordFrontUrl"));
        user.setIdCardBackUrl(paramsMap.get("idCordBackUrl"));
        user.setCreateTime(new Date());
        user.setCreateUser(paramsMap.get("userName"));
        if (ObjectUtil.isNotEmpty(paramsMap.get("address"))) {
            user.setAddress(paramsMap.get("address"));
        }
        user.setAccoutType(0);
        user.setIsRealName(1);

        QueryWrapper<SysUser> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("user_name", paramsMap.get("userName")).eq("id_card", paramsMap.get("idCord"));
        SysUser user2 = userMapper.selectOne(queryWrapper1);
        if (ObjectUtil.isNotEmpty(user2)) {
            return new Result(ResultCode.FAIL, "");
        }
        userMapper.insert(user);
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", paramsMap.get("phone"));
        SysUser user1 = userMapper.selectOne(queryWrapper);
        return new Result(ResultCode.SUCCESS,user1);
    }

    @Override
    public Result edit(HttpServletRequest httpServletRequest,SysUser user) {
        userMapper.updateById(user);
        return new Result(ResultCode.SUCCESS,"修改成功！");
    }

    @Override
    public Result list(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", paramsMap.get("phone"));
        return new Result(ResultCode.SUCCESS,userMapper.selectOne(queryWrapper));
    }

    @Override
    public Result findPhone(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String userName = paramsMap.get("userName");
        String idCord = paramsMap.get("idCord");
        String phone = paramsMap.get("phone");
        if (!phone.matches("1[3-9]\\d{9}")) {
            return new Result(ResultCode.FAIL, "手机号格式不正确");
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("user_name", userName).eq("id_card", idCord);
        SysUser user = userMapper.selectOne(queryWrapper);
        return new Result(ResultCode.SUCCESS, user.getPhone());
    }

    @Override
    public Result listPc(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        String word = paramsMap.get("word");
        String role = paramsMap.get("role");
        String pageSize = paramsMap.get("pageSize");
        String pageNum = paramsMap.get("pageSize");

        if (pageSize == null || pageSize == "") {
            pageSize = "10";
        }
        if (pageNum == null || pageNum == "") {
            pageNum = "1";
        }
        if (startTime != "") {
            startTime = startTime + " 00:00:00";
        }
        if (endTime != "") {
            endTime = endTime + " 23:59:59";
        }

        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("accout_type", 0).between("create_time", startTime, endTime)
                .eq("user_type", role).like("user_name", word).or().like("phone", word)
                .or().like("id_card", word);

        Page<SysUser> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        Page<SysUser> sysUserPage = userMapper.selectPage(page, queryWrapper);
        return new Result(ResultCode.SUCCESS,sysUserPage);
    }

    @Override
    public Result editState(HttpServletRequest httpServletRequest, SysUser user) {
        userMapper.updateById(user);
        return new Result(ResultCode.SUCCESS);
    }

    @Override
    public Result listPc2(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        String word = paramsMap.get("word");
        String role = paramsMap.get("role");
        String pageSize = paramsMap.get("pageSize");
        String pageNum = paramsMap.get("pageSize");

        if (pageSize == null || pageSize == "") {
            pageSize = "10";
        }
        if (pageNum == null || pageNum == "") {
            pageNum = "1";
        }
        if (startTime != "") {
            startTime = startTime + " 00:00:00";
        }
        if (endTime != "") {
            endTime = endTime + " 23:59:59";
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("accout_type", 1).or().eq("accout_typr",4).between("create_time", startTime, endTime)
                .eq("user_type", role).like("user_name", word).or().like("phone", word)
                .or().like("id_card", word);

        Page<SysUser> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        Page<SysUser> sysUserPage = userMapper.selectPage(page, queryWrapper);
        return new Result(ResultCode.SUCCESS,sysUserPage);
    }

}
